SELECT 10/asyncmy - Criterion.rs

## SELECT 10/asyncmy

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0036495 | 0.0037834 | 0.0036414
Mean | 17.891 ms | 18.087 ms | 18.288 ms
Std. Dev. | 906.83 µs | 1.0227 ms | 1.1216 ms
Median | 17.444 ms | 17.800 ms | 18.459 ms
MAD | 780.89 µs | 1.1362 ms | 1.5418 ms

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.